autoconfigurable - no members
=============================

Without the ``members`` option, one may expect no members to show up, but we
present all configurable traits still, including inherited configurable traits,
see `Issue27`_.

.. _Issue27: https://github.com/jupyterhub/autodoc-traits/issues/27

.. autoconfigurable:: sample_module.SampleConfigurableSubclass
   :noindex:
